@@ -7,7 +7,7 @@ from collections.abc import Awaitable, Callable
 
 import aiohttp
 
-from roborock.containers import (
+from roborock.data import (
     HomeData,
     HomeDataDevice,
     HomeDataProduct,
@@ -116,11 +116,16 @@ def create_home_data_api(
     This function creates a wrapper around the Roborock API client to fetch
     home data for the user.
     """
-
     # Note: This will auto discover the API base URL. This can be improved
     # by caching this next to `UserData` if needed to avoid unnecessary API calls.
     client = RoborockApiClient(username=email, base_url=base_url, session=session)
 
+    return create_home_data_from_api_client(client, user_data)
+
+
+def create_home_data_from_api_client(client: RoborockApiClient, user_data: UserData) -> HomeDataApi:
+    """Create a home data API wrapper from an existing API client."""
+
     async def home_data_api() -> HomeData:
         return await client.get_home_data_v3(user_data)
 
@@ -152,11 +157,13 @@ async def create_device_manager(
             case DeviceVersion.V1:
                 channel = create_v1_channel(user_data, mqtt_params, mqtt_session, device, cache)
                 trait = v1.create(
+                    device.duid,
                     product,
                     home_data,
                     channel.rpc_channel,
                     channel.mqtt_rpc_channel,
                     channel.map_rpc_channel,
+                    cache,
                     map_parser_config=map_parser_config,
                 )
             case DeviceVersion.A01:
@@ -167,7 +174,7 @@ async def create_device_manager(
                 trait = b01.create(channel)
             case _:
                 raise NotImplementedError(f"Device {device.name} has unsupported version {device.pv}")
-        return RoborockDevice(device, channel, trait)
+        return RoborockDevice(device, product, channel, trait)
 
     manager = DeviceManager(home_data_api, device_creator, mqtt_session=mqtt_session, cache=cache)
     await manager.discover_devices()
